@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::OutputStartup;
 
-our $DATE = '2017-06-30'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-07-02'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,6 +33,7 @@ our %output_modules = (
 
 our $scenario = {
     modules => {
+        'Log::ger::Output::Composite' => {version=>'0.005'},
     },
     participants => [
         {name=>"baseline", perl_cmdline => ["-e1"]},
@@ -70,7 +71,7 @@ Bencher::Scenario::LogGer::OutputStartup
 
 =head1 VERSION
 
-This document describes version 0.008 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-30.
+This document describes version 0.009 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-07-02.
 
 =head1 SYNOPSIS
 
@@ -92,13 +93,13 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Output::Array> 0.011
+L<Log::ger::Output::Array> 0.012
 
 L<Log::ger::Output::ArrayWithLimits> 0.001
 
 L<Log::ger::Output::Callback> 0.001
 
-L<Log::ger::Output::Composite> 0.004
+L<Log::ger::Output::Composite> 0.007
 
 L<Log::ger::Output::DirWriteRotate> 0.002
 
@@ -110,11 +111,11 @@ L<Log::ger::Output::LogAny> 0.006
 
 L<Log::ger::Output::LogDispatchOutput> 0.001
 
-L<Log::ger::Output::Null> 0.011
+L<Log::ger::Output::Null> 0.012
 
 L<Log::ger::Output::Screen> 0.005
 
-L<Log::ger::Output::String> 0.011
+L<Log::ger::Output::String> 0.012
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -272,7 +273,7 @@ L<Log::ger::Output::String>
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
 
@@ -280,31 +281,31 @@ Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
  +-----------------------------+-----------+-----------+------------+-----------+---------+
  | participant                 | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
  +-----------------------------+-----------+-----------+------------+-----------+---------+
- | init-with-FileWriteRotate   |        32 |      31   |        1   |   0.00012 |      21 |
- | init-with-LogDispatchOutput |        56 |      18   |        1.7 | 3.7e-05   |      20 |
- | init-with-LogAny            |        77 |      13   |        2.4 | 4.1e-05   |      21 |
- | init-with-Composite         |        88 |      11   |        2.7 | 3.7e-05   |      20 |
- | init-with-DirWriteRotate    |        95 |      10   |        2.9 | 2.6e-05   |      22 |
- | init-with-ArrayWithLimits   |       130 |       7.8 |        3.9 | 3.8e-05   |      20 |
- | init-with-Screen            |       130 |       7.8 |        3.9 | 1.3e-05   |      20 |
- | init-with-Null              |       130 |       7.8 |        4   | 3.6e-05   |      20 |
- | init-with-File              |       130 |       7.7 |        4   |   2e-05   |      21 |
- | init-with-Array             |       130 |       7.7 |        4   | 2.3e-05   |      20 |
- | init-with-Callback          |       130 |       7.7 |        4   | 3.5e-05   |      20 |
- | init-with-String            |       130 |       7.7 |        4   | 3.8e-05   |      20 |
- | load-LogDispatchOutput      |       150 |       6.8 |        4.5 | 2.1e-05   |      20 |
- | load-Screen                 |       150 |       6.7 |        4.6 | 2.2e-05   |      20 |
- | load-Composite              |       200 |       4.9 |        6.3 | 1.1e-05   |      20 |
- | load-DirWriteRotate         |       210 |       4.7 |        6.6 | 1.5e-05   |      20 |
- | load-String                 |       220 |       4.6 |        6.6 | 1.9e-05   |      20 |
- | load-File                   |       220 |       4.6 |        6.7 | 1.1e-05   |      20 |
- | load-ArrayWithLimits        |       220 |       4.6 |        6.7 | 2.1e-05   |      20 |
- | load-Callback               |       220 |       4.6 |        6.7 | 1.3e-05   |      20 |
- | load-FileWriteRotate        |       220 |       4.5 |        6.8 | 1.6e-05   |      20 |
- | load-LogAny                 |       220 |       4.5 |        6.8 | 1.1e-05   |      20 |
- | load-Array                  |       220 |       4.5 |        6.9 | 2.1e-05   |      21 |
- | load-Null                   |       320 |       3.1 |        9.8 | 1.5e-05   |      21 |
- | baseline                    |       360 |       2.8 |       11   | 4.5e-06   |      20 |
+ | init-with-FileWriteRotate   |      20.4 |      49   |        1   | 4.3e-05   |      20 |
+ | init-with-LogDispatchOutput |      35   |      29   |        1.7 | 4.6e-05   |      20 |
+ | init-with-LogAny            |      53   |      19   |        2.6 |   5e-05   |      21 |
+ | init-with-Composite         |      56   |      18   |        2.7 |   0.00011 |      20 |
+ | init-with-DirWriteRotate    |      60   |      17   |        2.9 | 7.8e-05   |      21 |
+ | init-with-Screen            |      78   |      13   |        3.8 | 5.1e-05   |      20 |
+ | init-with-File              |      78   |      13   |        3.8 | 4.3e-05   |      20 |
+ | init-with-Null              |      79   |      13   |        3.9 | 5.7e-05   |      21 |
+ | init-with-Array             |      79   |      13   |        3.9 | 3.6e-05   |      20 |
+ | init-with-String            |      79   |      13   |        3.9 | 4.2e-05   |      20 |
+ | init-with-Callback          |      80   |      12   |        3.9 | 4.1e-05   |      20 |
+ | init-with-ArrayWithLimits   |      80   |      12   |        3.9 | 3.7e-05   |      20 |
+ | load-Screen                 |      90   |      11   |        4.4 | 1.5e-05   |      20 |
+ | load-LogDispatchOutput      |      91   |      11   |        4.5 | 2.7e-05   |      20 |
+ | load-Composite              |     120   |       8.5 |        5.7 | 2.8e-05   |      20 |
+ | load-LogAny                 |     130   |       7.8 |        6.3 | 3.6e-05   |      20 |
+ | load-File                   |     130   |       7.8 |        6.3 | 2.2e-05   |      20 |
+ | load-FileWriteRotate        |     130   |       7.7 |        6.3 | 1.6e-05   |      20 |
+ | load-String                 |     130   |       7.7 |        6.4 | 1.6e-05   |      21 |
+ | load-Array                  |     130   |       7.7 |        6.4 | 3.7e-05   |      20 |
+ | load-ArrayWithLimits        |     130   |       7.6 |        6.4 | 9.9e-06   |      20 |
+ | load-Callback               |     130   |       7.6 |        6.4 | 2.5e-05   |      21 |
+ | load-DirWriteRotate         |     130   |       7.5 |        6.5 | 2.3e-05   |      20 |
+ | load-Null                   |     190   |       5.4 |        9.1 | 2.1e-05   |      20 |
+ | baseline                    |     200   |       5   |        9.7 | 7.4e-06   |      20 |
  +-----------------------------+-----------+-----------+------------+-----------+---------+
 
 
@@ -314,19 +315,19 @@ Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant                         | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Output::Screen            | 852                          | 4.1                | 20             |       6.6 |                    3.9 |        1   | 1.8e-05 |      20 |
- | Log::ger::Output::LogDispatchOutput | 848                          | 4.1                | 20             |       6.5 |                    3.8 |        1   | 2.6e-05 |      20 |
- | Log::ger::Output::Composite         | 848                          | 4.1                | 20             |       5.1 |                    2.4 |        1.3 | 2.4e-05 |      20 |
- | Log::ger::Output::File              | 856                          | 4.1                | 20             |       4.6 |                    1.9 |        1.4 | 1.7e-05 |      21 |
- | Log::ger::Output::ArrayWithLimits   | 844                          | 4.1                | 20             |       4.6 |                    1.9 |        1.4 | 1.6e-05 |      20 |
- | Log::ger::Output::Array             | 844                          | 4.1                | 20             |       4.6 |                    1.9 |        1.4 | 1.5e-05 |      20 |
- | Log::ger::Output::DirWriteRotate    | 852                          | 4.1                | 20             |       4.6 |                    1.9 |        1.4 | 1.4e-05 |      20 |
- | Log::ger::Output::String            | 852                          | 4.1                | 20             |       4.6 |                    1.9 |        1.4 | 2.5e-05 |      20 |
- | Log::ger::Output::LogAny            | 956                          | 4.2                | 20             |       4.6 |                    1.9 |        1.4 | 1.7e-05 |      20 |
- | Log::ger::Output::FileWriteRotate   | 952                          | 4.2                | 20             |       4.5 |                    1.8 |        1.5 | 1.7e-05 |      20 |
- | Log::ger::Output::Callback          | 848                          | 4.1                | 20             |       4.5 |                    1.8 |        1.5 | 1.2e-05 |      21 |
- | Log::ger::Output::Null              | 848                          | 4.1                | 20             |       3.1 |                    0.4 |        2.1 | 1.3e-05 |      20 |
- | perl -e1 (baseline)                 | 836                          | 4.1                | 20             |       2.7 |                    0   |        2.4 | 4.2e-06 |      20 |
+ | Log::ger::Output::Screen            | 864                          | 4.2                | 16             |      11   |                    6   |        1   | 1.7e-05 |      26 |
+ | Log::ger::Output::LogDispatchOutput | 856                          | 4.1                | 16             |      11   |                    6   |        1   | 2.3e-05 |      20 |
+ | Log::ger::Output::Composite         | 856                          | 4.2                | 16             |       8.6 |                    3.6 |        1.3 | 3.2e-05 |      20 |
+ | Log::ger::Output::String            | 864                          | 4.2                | 16             |       7.8 |                    2.8 |        1.4 | 3.1e-05 |      20 |
+ | Log::ger::Output::File              | 864                          | 4.1                | 16             |       7.8 |                    2.8 |        1.4 | 3.3e-05 |      20 |
+ | Log::ger::Output::Callback          | 860                          | 4.1                | 16             |       7.7 |                    2.7 |        1.4 | 3.2e-05 |      20 |
+ | Log::ger::Output::ArrayWithLimits   | 860                          | 4.1                | 16             |       7.7 |                    2.7 |        1.4 | 2.8e-05 |      21 |
+ | Log::ger::Output::DirWriteRotate    | 864                          | 4.1                | 16             |       7.7 |                    2.7 |        1.4 | 2.4e-05 |      20 |
+ | Log::ger::Output::LogAny            | 1000                         | 4.3                | 16             |       7.7 |                    2.7 |        1.4 | 2.1e-05 |      20 |
+ | Log::ger::Output::FileWriteRotate   | 1000                         | 4.3                | 16             |       7.7 |                    2.7 |        1.4 | 2.9e-05 |      20 |
+ | Log::ger::Output::Array             | 860                          | 4.1                | 16             |       7.6 |                    2.6 |        1.4 | 2.1e-05 |      20 |
+ | Log::ger::Output::Null              | 856                          | 4.1                | 16             |       5.3 |                    0.3 |        2.1 | 6.7e-06 |      20 |
+ | perl -e1 (baseline)                 | 844                          | 4.1                | 16             |       5   |                    0   |        2.2 | 6.5e-06 |      20 |
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
