@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::StringLevel;
 
-our $DATE = '2017-06-30'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-07-02'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ Bencher::Scenario::LogGer::StringLevel - Benchmark string_level()
 
 =head1 VERSION
 
-This document describes version 0.008 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-30.
+This document describes version 0.009 of Bencher::Scenario::LogGer::StringLevel (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-07-02.
 
 =head1 SYNOPSIS
 
@@ -60,7 +60,7 @@ Packaging a benchmark script as a Bencher scenario makes it convenient to includ
 
 Version numbers shown below are the versions used when running the sample benchmark.
 
-L<Log::ger::Util> 0.011
+L<Log::ger::Util> 0.012
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -88,7 +88,7 @@ Function call template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.5 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
 
 Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
 
@@ -96,8 +96,8 @@ Benchmark with default options (C<< bencher -m LogGer::StringLevel >>):
  +---------+-----------+-----------+------------+---------+---------+
  | dataset | rate (/s) | time (ns) | vs_slowest |  errors | samples |
  +---------+-----------+-----------+------------+---------+---------+
- | 1       |   1295190 |   772.086 |          1 |   0     |      20 |
- | warn    |   7800000 |   130     |          6 | 1.8e-10 |      27 |
+ | 1       |    714000 |  1400     |    1       | 4.2e-10 |      20 |
+ | warn    |   4622980 |   216.311 |    6.47213 |   0     |      20 |
  +---------+-----------+-----------+------------+---------+---------+
 
 
@@ -107,8 +107,8 @@ Benchmark module startup overhead (C<< bencher -m LogGer::StringLevel --module-s
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Util      | 0.82                         | 4.1                | 20             |       6.4 |                    3.6 |        1   | 3.6e-05 |      20 |
- | perl -e1 (baseline) | 1.3                          | 4.6                | 20             |       2.8 |                    0   |        2.3 | 5.5e-06 |      21 |
+ | Log::ger::Util      | 0.82                         | 4.1                | 16             |      10   |                    4.9 |        1   | 5.5e-05 |      20 |
+ | perl -e1 (baseline) | 1.3                          | 4.6                | 16             |       5.1 |                    0   |        2.1 | 7.1e-06 |      20 |
  +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
